@@ -4,11 +4,12 @@ import sys
 import time
 from typing import List, Any, Mapping, Union
 import pytest
+from unittest import mock
 
 import sentry_sdk
 import sentry_sdk.logger
 from sentry_sdk import get_client
-from sentry_sdk.envelope import Envelope
+from sentry_sdk.envelope import Envelope, Item, PayloadRef
 from sentry_sdk.types import Log
 from sentry_sdk.consts import SPANDATA, VERSION
 
@@ -310,7 +311,7 @@ def test_logs_tied_to_transactions(sentry_init, capture_envelopes):
     """
     Log messages are also tied to transactions.
     """
-    sentry_init(enable_logs=True)
+    sentry_init(enable_logs=True, traces_sample_rate=1.0)
     envelopes = capture_envelopes()
 
     with sentry_sdk.start_transaction(name="test-transaction") as trx:
@@ -326,7 +327,7 @@ def test_logs_tied_to_spans(sentry_init, capture_envelopes):
     """
     Log messages are also tied to spans.
     """
-    sentry_init(enable_logs=True)
+    sentry_init(enable_logs=True, traces_sample_rate=1.0)
     envelopes = capture_envelopes()
 
     with sentry_sdk.start_transaction(name="test-transaction"):
@@ -446,3 +447,84 @@ def test_logs_with_literal_braces(
         assert logs[0]["attributes"]["sentry.message.template"] == message
     else:
         assert "sentry.message.template" not in logs[0]["attributes"]
+
+
+@minimum_python_37
+def test_batcher_drops_logs(sentry_init, monkeypatch):
+    sentry_init(enable_logs=True, server_name="test-server", release="1.0.0")
+    client = sentry_sdk.get_client()
+
+    def no_op_flush():
+        pass
+
+    monkeypatch.setattr(client.log_batcher, "_flush", no_op_flush)
+
+    lost_event_calls = []
+
+    def record_lost_event(reason, data_category=None, item=None, *, quantity=1):
+        lost_event_calls.append((reason, data_category, item, quantity))
+
+    monkeypatch.setattr(client.log_batcher, "_record_lost_func", record_lost_event)
+
+    for i in range(1_005):  # 5 logs over the hard limit
+        sentry_sdk.logger.info("This is a 'info' log...")
+
+    assert len(lost_event_calls) == 5
+
+    for lost_event_call in lost_event_calls:
+        reason, data_category, item, quantity = lost_event_call
+
+        assert reason == "queue_overflow"
+        assert data_category == "log_item"
+        assert quantity == 1
+
+        assert item.type == "log"
+        assert item.headers == {
+            "type": "log",
+            "item_count": 1,
+            "content_type": "application/vnd.sentry.items.log+json",
+        }
+        assert item.payload.json == {
+            "items": [
+                {
+                    "body": "This is a 'info' log...",
+                    "level": "info",
+                    "timestamp": mock.ANY,
+                    "trace_id": mock.ANY,
+                    "attributes": {
+                        "sentry.environment": {
+                            "type": "string",
+                            "value": "production",
+                        },
+                        "sentry.release": {
+                            "type": "string",
+                            "value": "1.0.0",
+                        },
+                        "sentry.sdk.name": {
+                            "type": "string",
+                            "value": mock.ANY,
+                        },
+                        "sentry.sdk.version": {
+                            "type": "string",
+                            "value": VERSION,
+                        },
+                        "sentry.severity_number": {
+                            "type": "integer",
+                            "value": 9,
+                        },
+                        "sentry.severity_text": {
+                            "type": "string",
+                            "value": "info",
+                        },
+                        "sentry.trace.parent_span_id": {
+                            "type": "string",
+                            "value": mock.ANY,
+                        },
+                        "server.address": {
+                            "type": "string",
+                            "value": "test-server",
+                        },
+                    },
+                }
+            ]
+        }
