@@ -16,6 +16,8 @@ from sentry_sdk.scope import (
     use_isolation_scope,
     use_scope,
     should_send_default_pii,
+    register_external_propagation_context,
+    remove_external_propagation_context,
 )
 
 
@@ -971,3 +973,47 @@ def test_handle_error_on_token_reset_isolation_scope(error_cls, scope_manager):
 
                 mock_capture.assert_called_once()
                 mock_current_scope.reset.assert_called_once_with(mock_current_token)
+
+
+def test_trace_context_tracing(sentry_init):
+    sentry_init(traces_sample_rate=1.0)
+
+    with sentry_sdk.start_transaction(name="trx") as transaction:
+        with sentry_sdk.start_span(op="span1"):
+            with sentry_sdk.start_span(op="span2") as span:
+                trace_context = sentry_sdk.get_current_scope().get_trace_context()
+
+    assert trace_context["trace_id"] == transaction.trace_id
+    assert trace_context["span_id"] == span.span_id
+    assert trace_context["parent_span_id"] == span.parent_span_id
+    assert "dynamic_sampling_context" in trace_context
+
+
+def test_trace_context_external_tracing(sentry_init):
+    sentry_init()
+
+    def external_propagation_context():
+        return ("trace_id_foo", "span_id_bar")
+
+    register_external_propagation_context(external_propagation_context)
+
+    trace_context = sentry_sdk.get_current_scope().get_trace_context()
+
+    assert trace_context["trace_id"] == "trace_id_foo"
+    assert trace_context["span_id"] == "span_id_bar"
+
+    remove_external_propagation_context()
+
+
+def test_trace_context_without_performance(sentry_init):
+    sentry_init()
+
+    with sentry_sdk.isolation_scope() as isolation_scope:
+        trace_context = sentry_sdk.get_current_scope().get_trace_context()
+
+    propagation_context = isolation_scope._propagation_context
+    assert propagation_context is not None
+    assert trace_context["trace_id"] == propagation_context.trace_id
+    assert trace_context["span_id"] == propagation_context.span_id
+    assert trace_context["parent_span_id"] == propagation_context.parent_span_id
+    assert "dynamic_sampling_context" in trace_context
