@@ -25,7 +25,7 @@ from sentry_sdk import (
     Hub,
 )
 from sentry_sdk._compat import PY37, PY38
-from sentry_sdk.envelope import Envelope, Item, parse_json
+from sentry_sdk.envelope import Envelope, Item, parse_json, PayloadRef
 from sentry_sdk.transport import (
     KEEP_ALIVE_SOCKET_OPTIONS,
     _parse_rate_limits,
@@ -591,7 +591,110 @@ def test_complex_limits_without_data_category(
 
 
 @pytest.mark.parametrize("response_code", [200, 429])
-def test_log_item_limits(capturing_server, response_code, make_client):
+@pytest.mark.parametrize(
+    "item",
+    [
+        Item(payload=b"{}", type="log"),
+        Item(
+            type="log",
+            content_type="application/vnd.sentry.items.log+json",
+            headers={
+                "item_count": 2,
+            },
+            payload=PayloadRef(
+                json={
+                    "items": [
+                        {
+                            "body": "This is a 'info' log...",
+                            "level": "info",
+                            "timestamp": datetime(
+                                2025, 1, 1, tzinfo=timezone.utc
+                            ).timestamp(),
+                            "trace_id": "00000000-0000-0000-0000-000000000000",
+                            "attributes": {
+                                "sentry.environment": {
+                                    "value": "production",
+                                    "type": "string",
+                                },
+                                "sentry.release": {
+                                    "value": "1.0.0",
+                                    "type": "string",
+                                },
+                                "sentry.sdk.name": {
+                                    "value": "sentry.python",
+                                    "type": "string",
+                                },
+                                "sentry.sdk.version": {
+                                    "value": "2.45.0",
+                                    "type": "string",
+                                },
+                                "sentry.severity_number": {
+                                    "value": 9,
+                                    "type": "integer",
+                                },
+                                "sentry.severity_text": {
+                                    "value": "info",
+                                    "type": "string",
+                                },
+                                "server.address": {
+                                    "value": "test-server",
+                                    "type": "string",
+                                },
+                            },
+                        },
+                        {
+                            "body": "The recorded value was '2.0'",
+                            "level": "warn",
+                            "timestamp": datetime(
+                                2025, 1, 1, tzinfo=timezone.utc
+                            ).timestamp(),
+                            "trace_id": "00000000-0000-0000-0000-000000000000",
+                            "attributes": {
+                                "sentry.message.parameter.float_var": {
+                                    "value": 2.0,
+                                    "type": "double",
+                                },
+                                "sentry.message.template": {
+                                    "value": "The recorded value was '{float_var}'",
+                                    "type": "string",
+                                },
+                                "sentry.sdk.name": {
+                                    "value": "sentry.python",
+                                    "type": "string",
+                                },
+                                "sentry.sdk.version": {
+                                    "value": "2.45.0",
+                                    "type": "string",
+                                },
+                                "server.address": {
+                                    "value": "test-server",
+                                    "type": "string",
+                                },
+                                "sentry.environment": {
+                                    "value": "production",
+                                    "type": "string",
+                                },
+                                "sentry.release": {
+                                    "value": "1.0.0",
+                                    "type": "string",
+                                },
+                                "sentry.severity_number": {
+                                    "value": 13,
+                                    "type": "integer",
+                                },
+                                "sentry.severity_text": {
+                                    "value": "warn",
+                                    "type": "string",
+                                },
+                            },
+                        },
+                    ]
+                }
+            ),
+        ),
+    ],
+)
+def test_log_item_limits(capturing_server, response_code, item, make_client):
     client = make_client()
     capturing_server.respond_with(
         code=response_code,
@@ -601,7 +704,7 @@ def test_log_item_limits(capturing_server, response_code, make_client):
     )
 
     envelope = Envelope()
-    envelope.add_item(Item(payload=b"{}", type="log"))
+    envelope.add_item(item)
     client.transport.capture_envelope(envelope)
     client.flush()
 
@@ -622,9 +725,22 @@ def test_log_item_limits(capturing_server, response_code, make_client):
     envelope = capturing_server.captured[1].envelope
     assert envelope.items[0].type == "client_report"
     report = parse_json(envelope.items[0].get_bytes())
-    assert report["discarded_events"] == [
-        {"category": "log_item", "reason": "ratelimit_backoff", "quantity": 1},
-    ]
+
+    assert {
+        "category": "log_item",
+        "reason": "ratelimit_backoff",
+        "quantity": 1,
+    } in report["discarded_events"]
+
+    expected_lost_bytes = 1243
+    if item.payload.bytes == b"{}":
+        expected_lost_bytes = 2
+
+    assert {
+        "category": "log_byte",
+        "reason": "ratelimit_backoff",
+        "quantity": expected_lost_bytes,
+    } in report["discarded_events"]
 
 
 def test_hub_cls_backwards_compat():
